<?php
/*
Plugin Name: Email Checker for Contact Form 7
Plugin URI: https://wordpress.org/plugins/email-checker-for-cf7/
Description: Add custom functionality to your contact forms to prevent spam inbox by bots and invalid contacts subscribing your newsletters. 
Author: Kalpraj Solutions 
Author URI: https://emails-checker.net
Version: 1.2
Text Domain: email-checker-for-cf7
 
Email Checker for Contact Form 7
Copyright (C) 2020, Kalpraj Solutions, support@kalprajsolutions.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

defined('ABSPATH') or die('Direct Access Restricted!'); // Check point to restrict direct access to the file

//check if contact form 7 is available or not.
add_action('admin_init', 'kprj_email_checker_has_parent_plugin');

function kprj_email_checker_has_parent_plugin()
{

	if (is_admin() && current_user_can("activate_plugins") && !is_plugin_active("contact-form-7/wp-contact-form-7.php")) {

		add_action('admin_notices', 'kprj_email_checker_nocf7_notice');

		deactivate_plugins(plugin_basename(__FILE__));

		$flag = (int) $_GET['activate'];

		if (isset($flag)) {

			unset($_GET['activate']);
		}
	}
}

function kprj_email_checker_nocf7_notice()
{

	$plugin_URL =  esc_url(admin_url('plugin-install.php?tab=search&s=contact+form+7'));

?>
	<div class="error">
		<p>
			<?php
			printf(__('%s must be installed and activated for the <b>Email Checker for Contact Form 7</b> plugin to work', 'email-checker-for-contact-form-7'), '<a href="' . $plugin_URL . '">Contact Form 7</a>');
			?>
		</p>
	</div>
	<?php
}
//check for cf7 finish

//check if access key is stored or not.

if(kprjCheckLiveApiStatus()){
		function kprj_email_check($emailAddress)
		{
				// Check the formatting is correct
				if (filter_var($emailAddress, FILTER_VALIDATE_EMAIL) === false) {
					return false;
				}

				$kprj_echecker_access_key = get_option('kprj_echecker_access_key');
				$response = wp_remote_get("https://emails-checker.net/api/check?access_key={$kprj_echecker_access_key}&email=" . $emailAddress);
				$body     = wp_remote_retrieve_body($response);
				$body	  = json_decode($body, true);
				$status = $body["status"];
				if ($status == 1) {
					return true;
				} else {
					return false;
				}
		}

		function kprj_custom_email_checker_filter($result, $tags)
		{

				$tags = new WPCF7_FormTag($tags);

				$type = $tags->type;
				$name = $tags->name;

				if ('email' == $type || 'email*' == $type) { // Only apply to fields with the form field name of "company-email"

					$email_value = sanitize_email($_POST[$name]);

					if (!kprj_email_check($email_value)) {
						//code commented to enable translations
						$result->invalidate($tags, __('Invalid Email Address!', 'contact-form-7-email-validation'));
					}
				}
				return $result;
		}

		add_filter('wpcf7_validate_email', 'kprj_custom_email_checker_filter', 20, 2); // Email field
		add_filter('wpcf7_validate_email*', 'kprj_custom_email_checker_filter', 20, 2); // Req. Email field
}

//check if access key is available or not and show warning		
if (empty(get_option('kprj_echecker_access_key'))){
			
	function kprj_no_accesskey_found(){	
		?>
		<div class="notice notice-warning is-dismissible">
		<p><?php _e( 'To get started with Email Checker for CF7, please <a href="/wp-admin/options-general.php?page=email-checker-for-cf7">enter your EmailsChecker API key on the settings of the plugin.</a>', 'email-checker-for-cf7' ); ?></p>
		</div>
		<?php
		}			
	add_action('admin_notices', 'kprj_no_accesskey_found');
}

function kprjCheckLiveApiStatus(){
	$kprj_echecker_access_key = get_option('kprj_echecker_access_key');
	//make sure access key is not empty
	if(!empty($kprj_echecker_access_key)){
		$response = wp_remote_get("https://emails-checker.net/api/credits?access_key=" . $kprj_echecker_access_key);
		$body     = wp_remote_retrieve_body($response);
		$body	  = json_decode($body, true);
		if (empty($body["success"])) {
			return true;
		}else{
			update_option('kprj_echecker_access_key_status', "INVALID KEY");
			update_option('kprj_echecker_access_key_status_color', "RED");
			return false;
		}
	}else{
		return false;
	}
}

//admin page functions
if (is_admin()) {
	function kprj_echecker_setting_link($links)
	{
		$kprj_settings_link = array(
			'<a href="' . admin_url('options-general.php?page=email-checker-for-cf7') . '">Settings</a>',
		);
		return array_merge($links, $kprj_settings_link);
	}
	add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'kprj_echecker_setting_link', 10, 2);

	function kprj_check_adminhtml()
	{

		if (!current_user_can('manage_options')) {
			wp_die(__('You do not have sufficient permissions to access this page.'));
		}

		if (!class_exists('WPCF7_Submission')) {
			echo '<span style="color:red">To use <strong> Email Checker for Contact Form 7 </strong> please update <strong>Contact Form 7</strong> plugin as current version is not supported.</span>';
			return;
		}

		if (!empty($_POST['update'])) {
			if (wp_verify_nonce($_POST["urev_name_nonce"],"urev_action_nonce")) {
				$kprj_echecker_access_key = !empty($_POST['kprj_echecker_access_key']) ? sanitize_text_field($_POST['kprj_echecker_access_key']) : '';
				update_option('kprj_echecker_access_key', $kprj_echecker_access_key);
				$updated = 1;
			}	
		} else {
			$kprj_echecker_access_key = get_option('kprj_echecker_access_key');
		}
		
		
		$kprjOutput = "";
			//if access key is empty remove color and status name
			if (empty($kprj_echecker_access_key)) {
				delete_option('kprj_echecker_access_key_status_color');
				delete_option('kprj_echecker_access_key_status');
			}

			if (!empty($kprj_echecker_access_key)) {

				$response = wp_remote_get("https://emails-checker.net/api/credits?access_key=" . $kprj_echecker_access_key);
				$body     = wp_remote_retrieve_body($response);
				$body	  = json_decode($body, true);
				if (empty($body["success"])) {

					update_option('kprj_echecker_access_key_status', "CONNECTED");
					update_option('kprj_echecker_access_key_status_color', "GREEN");
					$plan_name = $body["plan_name"];
					$credits_limit = $body["credits_limit"];
					$credits_available = $body["credits_available"];
					$next_renewal_date = $body["next_renewal_date"];
					$next_renewal_date = date_create($next_renewal_date);
					$next_renewal_date = date_format($next_renewal_date, "d-M-Y");
					$kprjOutput = '<ul>
											<li>
												<span type="text" style="width: 370px;color:green;" > Current Plan : ' . $plan_name . ' </span>
											</li>
										</ul>
										<ul>
											<li>
												<span type="number" style="width: 370px;color:green;" > Available Credits : ' . $credits_available . ' </span>
											</li>
										</ul>			
										<ul>
											<li>
												<span type="number" style="width: 370px;color:red;"> Credits Limit : ' . $credits_limit . ' </span>
											</li>
										</ul>			
										<ul>
											<li>
												<span type="text" style="width: 370px;"> Next Renewal Date : ' . $next_renewal_date . ' </span>
											</li>
										</ul>';
				} else {
					update_option('kprj_echecker_access_key_status', "INVALID KEY");
					update_option('kprj_echecker_access_key_status_color', "RED");
					$kprj_api_error = $body["error"]["info"];
					$kprjOutput = '<div class="error" role="alert">' . $kprj_api_error . '</div>';
				}
			}
			
			
	?>
		
		<style>
			.box-area {
				font-size: 15px;
				background: #fff;
				border: 1px solid #e5e5e5;
				margin-top: 10px;
				padding: 20px 20px 20px 20px;
				margin-right: 20px;
			}

			.box-area ul li {
				list-style-type: disc;
				margin-left: 30px;
			}

			pre {
				background: #f3f3f3;
				padding: 10px;
				margin-top: 20px;
			}

			.box-area h2 {
				border-bottom: 1px solid #ececec;
				padding-bottom: 10px;
			}
		</style>
		<br />
		<br />
		<div class="box-area">
			<h2>Introduction</h2>
			<a href="https://emails-checker.net" target="_blank"><img src="<?php echo plugin_dir_url(__FILE__) . 'assets/emails-checker-logo.png'; ?>" style="float: right; width: 190px;"></a>
			You can use <a href="https://emails-checker.net" target="_blank">Emails-Checker.NET API</a> to verify email a ddresses in real-time on your website. Emails Checker Real-Time API engine perform the following checks:
			<br>
			<ul>
				<li>DNS validation, including MX record lookup</li>
				<li>Disposable email address detection realtime</li>
				<li>Misspelled domain detection</li>
				<li>Email Syntax verification (IETF/RFC standard conformance)</li>
				<li>Mailbox existence checking</li>
				<li>Catch-All Testing</li>
				<li>Greylisting detection</li>
				<li>SMTP connection and availability checking</li>
				<ul>
					<br>
					<b>Note:</b><br>
					Our Plugin will do basic syntax checking on site to avoid spam emails and reduce api usage. Invalid Syntax Emails will not be count for API Credits usage its <b>FREE</b>.
					<br />
					<br />
					<b>Where to Get Free Credits?</b><br>
					You can register for a <a href="https://emails-checker.net/dashboard/register" target="_blank">FREE API key</a> (limited to 250 smtp email address checks).<br>
					If you have more than 250 contact forms submission monthly, please have a look at our very cheap pricing model <a href="https://emails-checker.net/#pricing" target="_blank">subscription plans</a> we offer.
		</div>

		<div class="box-area" style="font-size: 15px; background: #fff; border: 1px solid #e5e5e5; margin-top: 20px; padding: 0 20px 20px; margin-right: 20px;">
			<h2>Contact Form Email Checker Settings</h2>This plugin will check if your contact person have valid email or not.<br><br>
			<form action="<?php echo $_SERVER['REQUEST_URI']; ?>" method="POST">
			
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row">Status</th>
							<td>
								<span style="display: inline-block;margin-left: 1em;padding: 3px 6px;color: #fff;font-size: 12px;font-weight: 700;background-color:<?php if(empty(get_option('kprj_echecker_access_key_status_color'))){echo "gray";}else{echo get_option('kprj_echecker_access_key_status_color');} ?>"><?php if (empty(get_option('kprj_echecker_access_key_status'))){echo "NOT CONNECTED";}else{echo get_option('kprj_echecker_access_key_status');} ?></span>
							</td>
						</tr>


						<tr valign="top">
							<th scope="row"><label for="mailchimp_api_key">API Key</label></th>
							<td>
								<input type="hidden" value="1" name="update" />
								<!--wp_nonce_field for security-->
								<?php wp_nonce_field("urev_action_nonce", "urev_name_nonce"); ?>
								<input type="text" style="width: 370px; color:<?php echo get_option('kprj_echecker_access_key_status_color'); ?>;" value="<?php echo $kprj_echecker_access_key; ?>" name="kprj_echecker_access_key" /> 
								<p class="help">
									The API key for connecting with your Emails-Checket.net account. <a target="_blank" href="https://emails-checker.net/dashboard/">Get your API key here.</a>
								</p>

							</td>

						</tr>

					</tbody>
				</table>
				<br />
				<input type="submit" class="button-primary" value="Save Settings" />
			</form>
			<?php if (!empty($updated)) : ?>
				<p style="color:green;">Settings were updated successfully!</p>
			<?php endif; ?><br /><br />


			<?php
			//print output
			if ($kprjOutput != "") {
				echo $kprjOutput;
			}
			?>

		</div>
<?php
	}

	//add menu
	function kprj_echecker_addmenu()
	{
		add_submenu_page(
			'options-general.php',
			'Emails Checker for CF7',
			'Emails Checker for CF7',
			'manage_options',
			'email-checker-for-cf7',
			'kprj_check_adminhtml'
		);
	}
	add_action('admin_menu', 'kprj_echecker_addmenu');
}
